# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Library for error values used by GnuPG components
Name:		libgpg-error
Version:	1.10
Release:	2.0.cf.%{__distinit}%{__distvers}
URL:		ftp://ftp.gnupg.org/gcrypt/libgpg-error/
Source0:	ftp://ftp.gnupg.org/gcrypt/libgpg-error/libgpg-error-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/libgpg-error/libgpg-error-%{version}.tar.bz2.sig
Group:		System Environment/Libraries
License:	LGPLv2+
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildRequires:	gawk, gettext, /bin/hostname, symlinks
Requires(post): /sbin/ldconfig
Requires(postun): /sbin/ldconfig

%description
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon and possibly more in the future.

%package devel
Summary:	Development files for the libgpg-error package
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description devel
This is a library that defines common error values for all GnuPG
components.  Among these are GPG, GPGSM, GPGME, GPG-Agent, libgcrypt,
pinentry, SmartCard Daemon and possibly more in the future. This package
contains files necessary to develop applications using libgpg-error.

%prep
%setup -q

# The config script already suppresses the -L if it's /usr/lib, so cheat and
# set it to a value that we know will be suppressed.
sed -i -e 's|^libdir=@libdir@$|libdir=@exec_prefix@/lib|g' src/gpg-error-config.in

# Recode ChangeLog as UTF-8
iconv -f iso-8859-1 -t utf-8 < ChangeLog > ChangeLog.utf8
touch -r ChangeLog ChangeLog.utf8
mv -f ChangeLog.utf8 ChangeLog

%build
%configure --disable-static --disable-rpath --disable-languages

# Kill bogus RPATHs
sed -i 's|^sys_lib_dlsearch_path_spec="/lib /usr/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALL="install -p"

# Remove files we don't want packaged
rm -f %{buildroot}%{_libdir}/*.la

%find_lang %{name}

# Relocate the shared libraries to /%%{_lib}
mkdir -p %{buildroot}/%{_lib}
for shlib in %{buildroot}%{_libdir}/*.so*; do
	if [ -L ${shlib} ]; then
		shlib_target=$(basename $(readlink ${shlib}))
		rm ${shlib}
		[ $(basename ${shlib}) = libgpg-error.so ] && ln -s %{buildroot}/%{_lib}/${shlib_target} ${shlib}
	else
		mv ${shlib} %{buildroot}/%{_lib}/
	fi
done
symlinks -cs %{buildroot}%{_libdir}

# Add the soname symlink back in
/sbin/ldconfig -n %{buildroot}/%{_lib}/

%check
make check

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc COPYING COPYING.LIB AUTHORS README NEWS ChangeLog
%{_bindir}/gpg-error
/%{_lib}/libgpg-error.so.0
/%{_lib}/libgpg-error.so.0.*

%files devel
%defattr(-,root,root,-)
%{_bindir}/gpg-error-config
%{_libdir}/libgpg-error.so
%{_includedir}/gpg-error.h
%{_datadir}/aclocal/gpg-error.m4

%changelog
* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.10-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sun Jul 17 2011 Paul Howarth <paul@city-fan.org> - 1.10-1.0.cf
- Update to 1.10:
  - New symbols: GPG_ERR_NOT_INITIALIZED, GPG_ERR_MISSING_ISSUER_CERT,
    GPG_ERR_FULLY_CANCELED  
  - Using a static library on W32 now works
- Fix dist tag for CentOS 6 and Scientific Linux
- Nobody else likes macros for commands

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.9-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Aug 16 2010 Paul Howarth <paul@city-fan.org> - 1.9-1.0.cf
- Update to 1.9:
  - New symbols: GPG_ERR_MISSING_KEY, GPG_ERR_TOO_MANY, GPG_ERR_LIMIT_REACHED
  - New function: gpg_err_deinit
  - Fix building of static lib under W32

* Mon Aug 16 2010 Paul Howarth <paul@city-fan.org> - 1.8-1.0.cf
- Update to 1.8:
  - Support for WindowsCE
  - New option --list for gpg-error
  - New symbols: GPG_ERR_NOT_ENABLED, GPG_ERR_SOURCE_G13, GPG_ERR_NO_ENGINE
  - New function: gpg_err_set_errno
- BR: /bin/hostname

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.7-4.0.cf
- Fix dist tag for RHEL-6 Beta

* Fri Feb 26 2010 Paul Howarth <paul@city-fan.org> - 1.7-3.0.cf
- Turn off common lisp bindings the right way
- Build with --disable-rpath
- Drop unused finger output
- Retain timestamps where possible

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> - 1.7-1.0.cf
- Long-overdue update to 1.7
- Dist tag for Rawhide no longer needs special-casing

* Sat Oct  3 2009 Paul Howarth <paul@city-fan.org> - 1.6-4.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar  3 2009 Paul Howarth <paul@city-fan.org> - 1.6-3.0.cf
- Import from Fedora
- Simplify library relocation to /%%{_lib} by using the symlinks program
- Recode ChangeLog as UTF-8
- Kill rpaths to /usr/lib64

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.6-2
- Autorebuild for GCC 4.3

* Fri Dec  7 2007 Nalin Dahyabhai <nalin@redhat.com>
- remove the generic install docs (#226021)

* Fri Dec  7 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.6-1
- update to 1.6
- add suggested summary, buildrequires, and modify install call as suggested
  by package review (#226021)

* Mon Oct 15 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-6
- use ldconfig to make the soname symlink so that it gets packaged (#331241)

* Wed Aug 22 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-5
- add missing gawk buildrequirement

* Thu Aug 16 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-4
- clarify license

* Mon Jul 30 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-3
- disable static libraries (part of #249815)

* Fri Jul 27 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-2
- move libgpg-error shared library to /%%{_lib} (#249816)

* Thu Jul 19 2007 Nalin Dahyabhai <nalin@redhat.com> - 1.5-1
- update to 1.5

* Sun Oct 01 2006 Jesse Keating <jkeating@redhat.com> - 1.4-2
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Mon Sep 18 2006 Bill Nottngham <notting@redhat.com> - 1.4-1
- update to 1.4
- don't ship lisp bindings

* Wed Jul 12 2006 Jesse Keating <jkeating@redhat.com> - 1.3-3.1
- rebuild

* Mon Jun  5 2006 Nalin Dahyabhai <nalin@redhat.com> 1.3-3
- give gpg-error-config libdir=@exec_prefix@/lib instead of @libdir@, so that
  it agrees on 32- and 64-bit arches (it suppresses the -L argument if @libdir@
  is /usr/lib, so this should be cleaner than adding a non-standard .pc file
  which upstream developers might inadvertently think they can depend to be on
  every system which provides this library)

* Mon May 15 2006 Karsten Hopp <karsten@redhat.de> 1.3-2
- switch to pkgconfig so that gpg-error-config can be the same on 
  32bit and 64bit archs

* Tue May  2 2006 Nalin Dahyabhai <nalin@redhat.com> - 1.3-1
- update to version 1.3

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 1.1-1.2.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jesse Keating <jkeating@redhat.com> - 1.1-1.2
- rebuilt for new gcc4.1 snapshot and glibc changes

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov 30 2005 Karsten Hopp <karsten@redhat.de> 1.1-1
- update

* Wed Mar  2 2005 Bill Nottingham <notting@redhat.com> - 1.0-2
- we can rebuild it. we have the technology.

* Tue Aug 31 2004 Bill Nottingham <notting@redhat.com> - 1.0-1
- update to 1.0

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Fri Apr 16 2004 Bill Nottingham <notting@redhat.com> - 0.7-1
- adapt upstream specfile
